@@ -4,10 +4,10 @@ from mlapp.integrations.aml.utils.runconfig import create_runconfig
 import os
 
 
-def run_script(ws, env, datastore, pipeline_name, compute_target, vm_size='STANDARD_D2_V2', min_nodes=0, max_nodes=4):
+def run_script(ws, datastore, pipeline_name, compute_target, vm_size='STANDARD_D2_V2', min_nodes=0, max_nodes=4):
     # init components
     compute_target = get_or_create_compute_target(ws, compute_target, vm_size, min_nodes, max_nodes)
-    run_config = create_runconfig(compute_target, env)
+    run_config = create_runconfig(compute_target)
 
     # create pipelines steps
     steps = create_mlapp_pipeline_step(
